==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/CGI/Request.pm <==
#
# WiKicker
#
#  Request.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Request.pm,v 1.13 2004/05/29 02:42:44 naney Exp $
#
#

package WiKicker::CGI::Request;

use strict;
use WiKicker::CGI::User;
use WiKicker::CGI::Cookie;
use WiKicker::L10N;
use WiKicker::LoadAverage;
use Carp;



sub param {
  my ($self, $name) = @_;

  return $self->query->param($name);
}

sub url {
  my $self = shift;

  #return $self->query->url;
  return $ENV{SCRIPT_NAME};
}

sub attribute {
  my ($self, $name, $value) = @_;

  if (defined $value) {
    return $self->{attribute}->{$name} = $value;
  }
  else {
    return $self->{attribute}->{$name};
  }
}

sub action {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{action} = $value;
  }
  return $self->{action};
}

sub query {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{query} = $value;
  }
  return $self->{query};
}

sub user {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{user} = $value;
  }
  return $self->{user};
}

sub cookies {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{cookies} = $value;
  }
  return $self->{cookies};
}

sub configuration {
  my ($self, $value) = @_;

  if (defined $value) {
    #$self->{configuration} = $value;
    confess "deprecated";
  }
  #return $self->{configuration};
  return defined $self->environment ?
           $self->environment->configuration : undef;
}

sub environment {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{environment} = $value;
  }
  return $self->{environment};
}

sub _initialize_user {
  my $self = shift;

  my $user = WiKicker::CGI::User->new;
  if ($self->configuration) {
    $user->timezone($self->configuration->properties->get('user.timezone'));
  }
  WiKicker::CGI::Cookie::set_user($self->cookies, $user);

  $self->user($user);
}

sub maketext {
  my ($self, @param) = @_;

  unless (exists $self->{_language_handle}) {
    $self->{_language_handle} = WiKicker::L10N->get_handle;
  }

  if (5.006 <= $] && $] < 5.7) {
      return eval "no utf8; my \$tmp = \$self->{_language_handle}->maketext(\@param); \$tmp =~ /^(.*)\$/; \$1";
  }

  return $self->{_language_handle}->maketext(@param);
}

sub lang {
  my $self = shift;

  $self->_get_language_handle;
  return $self->{_language_handle}->language_tag || 'en';
}

sub language_handle {
  my $self = shift;

  $self->_get_language_handle;
  return $self->{_language_handle};
}

sub _get_language_handle {
  my $self = shift;

  unless (exists $self->{_language_handle}) {
    $self->{_language_handle} = WiKicker::L10N->get_handle;
  }
}

sub load_average {
  my $self = shift;

  unless (defined $self->{load_average}) {
    $self->{load_average} = WiKicker::LoadAverage->new;
  }
  return $self->{load_average};
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/CGI/Request.pm <==
#
# WiKicker
#
#  Request.pm
#
#
# Copyright (C) 2003,2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Request.pm,v 1.16 2005/04/04 13:54:25 naney Exp $
#
#

package WiKicker::CGI::Request;

use strict;
use WiKicker::CGI::User;
use WiKicker::CGI::Cookie;
use WiKicker::L10N;
use WiKicker::LoadAverage;
use Carp;



sub param {
  my ($self, $name) = @_;

  return $self->query->param($name);
}

sub url {
  my $self = shift;

  if (exists $self->{_url}) {
    return $self->{_url};
  }

  unless (exists $ENV{SCRIPT_NAME}) {
    croak 'No SCRIPT_NAME environment variable';
  }

  return $self->{_url} = $ENV{SCRIPT_NAME};
}

sub attribute {
  my ($self, $name, $value) = @_;

  if (defined $value) {
    return $self->{attribute}->{$name} = $value;
  }
  else {
    return $self->{attribute}->{$name};
  }
}

sub action {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{action} = $value;
  }
  return $self->{action};
}

sub query {
  my $self = shift;

  #IFDEBUG: assert (scalar(@_) == 0)
  # use _set_query

  return $self->{query};
}

sub _set_query {
  my ($self, $query) = @_;

  $self->{query} = $query;
}

# same CGI::request_method;
sub request_method {
  return $ENV{REQUEST_METHOD};
}

sub user {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{user} = $value;
  }
  return $self->{user};
}

sub cookies {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{cookies} = $value;
  }
  return $self->{cookies};
}

sub configuration {
  my $self = shift;

  return defined $self->environment ?
           $self->environment->configuration : undef;
}

sub environment {
  my ($self, $value) = @_;

  if (defined $value) {
    $self->{environment} = $value;
  }
  return $self->{environment};
}

sub _initialize_user {
  my $self = shift;

  my $user = WiKicker::CGI::User->new;
  if ($self->configuration) {
    $user->timezone($self->configuration->properties->get('user.timezone'));
  }
  WiKicker::CGI::Cookie::set_user($self->cookies, $user);

  $self->user($user);
}

sub maketext {
  my ($self, @param) = @_;

  unless (exists $self->{_language_handle}) {
    $self->{_language_handle} = WiKicker::L10N->get_handle;
  }

  if (5.006 <= $] && $] < 5.7) {
      return eval "no utf8; my \$tmp = \$self->{_language_handle}->maketext(\@param); \$tmp =~ /^(.*)\$/; \$1";
  }

  return $self->{_language_handle}->maketext(@param);
}

sub lang {
  my $self = shift;

  $self->_get_language_handle;
  return $self->{_language_handle}->language_tag || 'en';
}

sub language_handle {
  my $self = shift;

  $self->_get_language_handle;
  return $self->{_language_handle};
}

sub _get_language_handle {
  my $self = shift;

  unless (exists $self->{_language_handle}) {
    $self->{_language_handle} = WiKicker::L10N->get_handle;
  }
}

sub load_average {
  my $self = shift;

  unless (defined $self->{load_average}) {
    $self->{load_average} = WiKicker::LoadAverage->new;
  }
  return $self->{load_average};
}

1;
